@@ -1,6 +1,6 @@
 from .experiment import Experiment, Evaluation, Filter, FilterScope
-from .metric import Metric
-from .check import Check, SrmCheck
+from .metric import Metric, SimpleMetric
+from .check import Check, SrmCheck, SimpleSrmCheck
 from .parser import Parser, EpGoal
 from .dao import Dao, DaoFactory
 from .statistics import Statistics
