@@ -258,6 +258,8 @@ class Experiment:
 
         It assumes that the first two columns are name of the experiment and variants. Than follows columns with data.
 
+        See usage of the method in the notebook [Ad-hoc A/B test evaluation using Ep-Stats](../user_guide/ab_test_simple_evaluation.html).
+
         Arguments:
             goals: dataframe with one row per variant and aggregated data in columns
 
@@ -677,7 +679,7 @@ class Experiment:
         # dimensions of `stats` array: (metrics, variants, stats)
         # elements of `stats` array: metrics_id, exp_variant_id, count, mean, std, sum_value, confidence_level
         # hypothesis evaluation (standard way using t-test)
-        c = Statistics.ttest_evaluation(stats)
+        c = Statistics.ttest_evaluation(stats, self.control_variant)
 
         # multiple variants (comparisons) correction - applied when we have multiple treatment variants
         if variants > 2:
